/*******************************************************************************
 * Copyright (c) 2013 Wind River Systems, Inc. and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v1.0 which accompany this distribution.
 * The Eclipse Public License is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * You may elect to redistribute this code under either of these licenses.
 *
 * Contributors:
 *     Wind River Systems - initial API and implementation
 *******************************************************************************/

#include <tcf/config.h>

extern RegisterDefinition * sys_get_PC_definition(Context * ctx);
extern int sys_crawl_stack_frame(StackFrame * frame, StackFrame * down);

#if ENABLE_ContextMux
#define get_PC_definition  sys_get_PC_definition
#if ENABLE_StackCrawlMux
#define crawl_stack_frame       sys_crawl_stack_frame
#endif /* ENABLE_StackCrawlMux */
#endif /* ENABLE_ContextMux */
